@@ -12,6 +12,8 @@ from .api import (
     MessageAPI,
     WebsocketAPI,
     MuteAPI,
+    AnnouncesAPI,
+    DmsAPI,
 )
 
 from .async_api import (
@@ -26,9 +28,11 @@ from .async_api import (
     AsyncMessageAPI,
     AsyncWebsocketAPI,
     AsyncMuteAPI,
+    AsyncAnnouncesAPI,
+    AsyncDmsAPI,
 )
 from .core.network.ws.ws_intents_handler import HandlerType, Handler
 from .core.util import logging
 from .model import *
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger()
