@@ -7,6 +7,11 @@ from qqbot.core.network.url import get_url, APIConstant
 from qqbot.core.network.ws.ws_intents_handler import Handler, register_handlers
 from qqbot.core.network.ws_sync.ws_session_manager import SessionManager
 from qqbot.core.util.json_util import JsonUtil
+from qqbot.model.announce import (
+    Announce,
+    CreateAnnounceRequest,
+    CreateChannelAnnounceRequest,
+)
 from qqbot.model.audio import AudioControl
 from qqbot.model.channel import (
     Channel,
@@ -460,6 +465,26 @@ class MessageAPI(APIBase):
         response = self.http.post(url, request_json)
         return json.loads(response.content, object_hook=Message)
 
+    def recall_message(self, channel_id: str, message_id: str):
+        """
+        撤回消息
+
+        管理员可以撤回普通成员的消息
+        频道主可以撤回所有人的消息
+
+        :param channel_id: 子频道ID
+        :param message_id: 消息ID
+        """
+        url = get_url(APIConstant.messageURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id
+        )
+        response = self.http.delete(url)
+        return response.status_code == HttpStatus.OK
+
+
+class DmsAPI(APIBase):
+    """私信消息"""
+
     def create_direct_message(
         self, create_direct_message: CreateDirectMessageRequest
     ) -> DirectMessageGuild:
@@ -528,8 +553,13 @@ class UserAPI(APIBase):
         :return:Guild对象列表
         """
         url = get_url(APIConstant.userMeGuildsURI, self.is_sandbox)
-        request_json = JsonUtil.obj2json_serialize(option)
-        response = self.http.get(url, request=request_json)
+
+        if option is None:
+            query = {}
+        else:
+            query = option.__dict__
+
+        response = self.http.get(url, params=query)
         return json.loads(response.content, object_hook=Guild)
 
 
@@ -574,3 +604,67 @@ class MuteAPI(APIBase):
         request_json = JsonUtil.obj2json_serialize(options)
         response = self.http.patch(url, request=request_json)
         return response.status_code == HttpStatus.NO_CONTENT
+
+
+class AnnouncesAPI(APIBase):
+    """公告接口"""
+
+    def create_announce(
+        self, guild_id: str, request: CreateAnnounceRequest
+    ) -> Announce:
+        """
+        创建频道全局公告
+
+        :param guild_id: 频道ID
+        :param request: CreateAnnounceRequest对象
+        """
+        url = get_url(APIConstant.guildAnnounceURI, self.is_sandbox).format(
+            guild_id=guild_id
+        )
+        request_json = JsonUtil.obj2json_serialize(request)
+        response = self.http.post(url, request_json)
+        return json.loads(response.content, object_hook=Announce)
+
+    def delete_announce(self, guild_id: str, message_id: str):
+        """
+        删除频道全局公告
+        message_id 有值时，会校验 message_id 合法性，若不校验校验 message_id，请将 message_id 设置为 all
+
+        :param guild_id: 频道ID
+        :param message_id: 消息ID
+        """
+        url = get_url(APIConstant.deleteGuildAnnounceURI, self.is_sandbox).format(
+            guild_id=guild_id, message_id=message_id
+        )
+        response = self.http.delete(url)
+        return response.status_code == HttpStatus.NO_CONTENT
+
+    def create_channel_announce(
+        self, channel_id: str, request: CreateChannelAnnounceRequest
+    ) -> Announce:
+        """
+        设置消息为指定子频道公告
+
+        :param channel_id: 频道ID
+        :param request: CreateChannelAnnounceRequest对象
+        """
+        url = get_url(APIConstant.channelAnnounceURI, self.is_sandbox).format(
+            channel_id=channel_id
+        )
+        request_json = JsonUtil.obj2json_serialize(request)
+        response = self.http.post(url, request_json)
+        return json.loads(response.content, object_hook=Announce)
+
+    def delete_channel_announce(self, channel_id: str, message_id: str):
+        """
+        删除子频道公告
+        message_id 有值时，会校验 message_id 合法性，若不校验校验 message_id，请将 message_id 设置为 all
+
+        :param channel_id: 频道ID
+        :param message_id: 消息ID
+        """
+        url = get_url(APIConstant.deleteChannelAnnounceURI, self.is_sandbox).format(
+            channel_id=channel_id, message_id=message_id
+        )
+        response = self.http.delete(url)
+        return response.status_code == HttpStatus.NO_CONTENT
