@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
 import logging
-import platform
 import os
+import platform
 from logging import FileHandler
-from logging.handlers import RotatingFileHandler
+from logging.handlers import TimedRotatingFileHandler
 
 LOG_COLORS_CONFIG = {
     "DEBUG": "cyan",
@@ -36,13 +36,19 @@ def _getLevel():
     return level
 
 
-def getLogger(name):
+def getLogger(name=None):
     print_format = (
-        """\033[1;33m%(levelname)s: %(name)s(line: %(lineno)s):\033[0m%(message)s"""
+        "%(asctime)s - "
+        "\033[1;33m%(levelname)s: %(name)s - %(filename)s - %(funcName)s(line: %(lineno)s):\033[0m%(message)s"
+        ""
     )
-    file_format = "%(asctime)s - %(name)s - %(filename)s - %(funcName)s - line %(lineno)s - %(levelname)s - %(message)s"
+    file_format = "%(asctime)s-%(name)s - %(filename)s - %(funcName)s - line %(lineno)s-%(levelname)s - %(message)s"
+
+    if name is None:
+        logger = logging.getLogger("qqbot")
+    else:
+        logger = logging.getLogger(name)
 
-    logger = logging.getLogger(name)
     logging.basicConfig(format=print_format)
     logger.setLevel(level=_getLevel())
 
@@ -50,15 +56,23 @@ def getLogger(name):
     no_log = os.getenv("QQBOT_DISABLE_LOG", "0")
     if no_log == "0":
         formatter = logging.Formatter(file_format)
-        log_file = os.path.join(os.getcwd(), "qqbot.log")
+        if name is None:
+            name = "qqbot"
+        log_file = os.path.join(os.getcwd(), name + ".log")
         file_handler = None
-        if platform.system().lower() != 'windows':
+        if platform.system().lower() != "windows":
             # do not use RotatingFileHandler under Windows
             # due to multi-process issue
-            file_handler = RotatingFileHandler(
-                log_file,
-                maxBytes=1024 * 1024,
-                backupCount=5,
+            # file_handler = RotatingFileHandler(
+            #     log_file,
+            #     maxBytes=1024 * 1024,
+            #     backupCount=5,
+            # )
+            # save last 7 days log
+            file_handler = TimedRotatingFileHandler(
+                filename=log_file,
+                when="D",
+                backupCount=7,
             )
         else:
             file_handler = FileHandler(log_file)
@@ -67,6 +81,7 @@ def getLogger(name):
         )
         file_handler.setLevel(level=_getLevel())
         file_handler.setFormatter(formatter)
-        logger.addHandler(file_handler)
+        if len(logger.handlers) == 0:
+            logger.addHandler(file_handler)
 
     return logger
